"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupLayer = void 0;
const listener_layes_1 = require("./listener.layes");
const help_1 = require("../../help");
const enum_1 = require("../../model/enum");
class GroupLayer extends listener_layes_1.ListenerLayer {
    constructor(page, browser, options, ev) {
        super(page, browser, options, ev);
        this.page = page;
        this.browser = browser;
        this.options = options;
        this.ev = ev;
    }
    /**
     * Get group participants
     * @param {string} groupId Group id exemple: 000000000000-0000000000@c.us
     */
    async getGroupParticipant(groupId) {
        return this.handleApiCallParametres(enum_1.FunctionsLayer.getGroupParticipant, groupId);
    }
    /**
     * Retrieve all groups
     */
    async getAllChatsGroups() {
        return this.handleApiCallParametres(enum_1.FunctionsLayer.getAllChatsGroups);
    }
    /**
     * Creates a new chat group
     * @param {string} groupName Group name
     * @param {(string | string[])} contacts Participants id '000000000000@c.us'
     */
    async createGroup(groupName, contacts) {
        return this.handleApiCallParametres(enum_1.FunctionsLayer.createGroup, groupName, contacts);
    }
    /**
     * Adds participant to Group
     * @param {string} groupId Chat id ('0000000000-00000000@g.us' or '000000000000000000@g.us')
     * @param {(string | string[])} contacts Participants id '000000000000@c.us'
     */
    async addParticipant(groupId, contacts) {
        return this.handleApiCallParametres(enum_1.FunctionsLayer.addParticipant, groupId, contacts);
    }
    /**
     * Parameters to change group description
     * @param {string} groupId group number
     * @param {string} description group description
     */
    async setGroupDescription(groupId, description) {
        return this.handleApiCallParametres(enum_1.FunctionsLayer.setGroupDescription, groupId, description);
    }
    /**
     * Parameters to change group image
     * @param {string} groupId group number
     * @param {string} path of image
     */
    async setGroupImage(groupId, path) {
        return new Promise(async (resolve, reject) => {
            let b64 = await (0, help_1.downloadFileToBase64)(path, [
                'image/gif',
                'image/png',
                'image/jpg',
                'image/jpeg',
                'image/webp',
            ]);
            if (!b64) {
                b64 = await (0, help_1.fileToBase64)(path);
            }
            if (b64) {
                const buff = Buffer.from(b64.replace(/^data:image\/(png|jpe?g|webp);base64,/, ''), 'base64');
                const mimeInfo = (0, help_1.base64MimeType)(b64);
                if (!mimeInfo || mimeInfo.includes('image')) {
                    let _webb64_96 = await (0, help_1.resizeImg)(buff, { width: 96, height: 96 }), _webb64_640 = await (0, help_1.resizeImg)(buff, { width: 640, height: 640 });
                    let obj = { a: _webb64_640, b: _webb64_96 };
                    const result = await this.page.evaluate(({ obj, groupId }) => API.setGroupImage(obj, groupId), {
                        obj,
                        groupId,
                    });
                    if (result.error == true) {
                        return reject(result);
                    }
                    else {
                        return resolve(result);
                    }
                }
                else {
                    console.log('Not an image, allowed formats png, jpeg and webp');
                    return false;
                }
            }
        });
    }
}
exports.GroupLayer = GroupLayer;
//# sourceMappingURL=group.layer.js.map